@@ -27,29 +27,26 @@ class HistoricCountries(pycountry.db.Database):
     """Provides access to an ISO 3166-3 database
     (Countries that have been removed from the standard)."""
 
-    # These fields are computed in a case-by-base basis
-    # `alpha_2` is not set in ISO-3166-3, so, we extract it from `alpha4`
-
     data_class_name = 'Country'
     root_key = '3166-3'
 
 
 class Scripts(pycountry.db.Database):
-    """Providess access to an ISO 15924 database (Scripts)."""
+    """Provides access to an ISO 15924 database (Scripts)."""
 
     data_class_name = 'Script'
     root_key = '15924'
 
 
 class Currencies(pycountry.db.Database):
-    """Providess access to an ISO 4217 database (Currencies)."""
+    """Provides access to an ISO 4217 database (Currencies)."""
 
     data_class_name = 'Currency'
     root_key = '4217'
 
 
 class Languages(pycountry.db.Database):
-    """Providess access to an ISO 639-1/2T/3 database (Languages)."""
+    """Provides access to an ISO 639-1/2T/3 database (Languages)."""
 
     no_index = ['status', 'scope', 'type', 'inverted_name', 'common_name']
     data_class_name = 'Language'
@@ -87,7 +84,7 @@ class Subdivisions(pycountry.db.Database):
 
     data_class_base = Subdivision
     data_class_name = 'Subdivision'
-    no_index = ['name', 'parent_code']
+    no_index = ['name', 'parent_code', 'parent', 'type']
     root_key = '3166-2'
 
     def _load(self, *args, **kw):
@@ -100,6 +97,18 @@ class Subdivisions(pycountry.db.Database):
                 subdivision.country_code, set())
             divs.add(subdivision)
 
+    def get(self, **kw):
+        try:
+            return super(Subdivisions, self).get(**kw)
+        except KeyError:
+            # This propagates a KeyError if the country does not exist and
+            # returns an empty list if it exists but it does not have (or we do
+            # not know about)  any sub-divisions.
+            if 'country_code' in kw:
+                countries.get(alpha_2=kw['country_code'])
+                return []
+            raise
+
 
 countries = ExistingCountries(os.path.join(DATABASE_DIR, 'iso3166-1.json'))
 historic_countries = HistoricCountries(
